# chilero
A micro framework... A la Tortrix!

[![Build Status](https://travis-ci.org/dmonroy/chilero.svg?branch=master)](https://travis-ci.org/dmonroy/chilero)

Because web application development is Chilero!
